@@ -6,5 +6,5 @@
 matlabbatch{1}.spm.spatial.normalise.write.subj.def = {'%deformation%'};
 matlabbatch{1}.spm.spatial.normalise.write.subj.resample = %resample%;
 matlabbatch{1}.spm.spatial.normalise.write.woptions.bb = %bbox%
-matlabbatch{1}.spm.spatial.normalise.write.woptions.vox = [2 2 2];
-matlabbatch{1}.spm.spatial.normalise.write.woptions.interp = 4;
+matlabbatch{1}.spm.spatial.normalise.write.woptions.vox = %vox%;
+matlabbatch{1}.spm.spatial.normalise.write.woptions.interp = %interp%;
